#define BUFFER_SIZE 6

#define JAMMERIMGPATH DATA_DIR "/jammer"

#define JAMMERSOUNDPATH AUDIO_DIR "/jammersounds"

void start_jammer();
